@@ -1804,6 +1804,9 @@ class clip:
 		SecondClip.video_fade_out = self.video_fade_out
 		SecondClip.video_fade_amount = self.video_fade_amount
 
+		# copy original properties
+		SecondClip.keyframes = self.keyframes
+
 		# render new clip
 		SecondClip.RenderClip()
 		
