@@ -17,7 +17,7 @@
 #	along with OpenShot Video Editor.  If not, see <http://www.gnu.org/licenses/>.
 
 from classes import messagebox
-import os, sys, urllib, uuid, re
+import os, sys, urllib, uuid, re, glob
 import gtk
 
 # init the foreign language
@@ -220,8 +220,8 @@ class OpenShotFolder:
 
 		# Get just the file name
 		(dirName, fileName) = os.path.split(file_path)
-		image_parts = re.compile(r"([a-zA-Z-_ ]+[0-9]*?[-_ ]*)(0*)(\d+)\.{1}(\w{3,4})")
-		match = image_parts.findall(fileName)
+		extensions = ["png", "jpg", "jpeg", "gif"]
+		match = re.findall(r"(.*[^\d])?(0*)(\d+)\.(%s)" % "|".join(extensions), fileName, re.I)
 		
 		if not match:
 			# File name does not match an image sequence
@@ -229,24 +229,29 @@ class OpenShotFolder:
 		else:
 			# Get the parts of image name
 			base_name = match[0][0]
-			zeros = match[0][1]
+			fixlen = match[0][1] > ""
 			number = int(match[0][2])
+			digits = len(match[0][1] + match[0][2])
 			extension = match[0][3]
-			has_previous_image = False
-			has_next_image = False
-			parameters = {"file_path": file_path, "folder_path":dirName, "base_name":base_name, "zeros":zeros, "number":number, "extension":extension}
+
+			full_base_name = os.path.join(dirName, base_name)
 			
-			# Check for previous image
-			if extension.lower() in ["png", "jpg", "jpeg", "gif"]:
-				if os.path.exists(os.path.join(dirName, "%s%s%s.%s" % (base_name, zeros, number - 1, extension))):
-					has_previous_image = True
-					
-				# Check for next image
-				if os.path.exists(os.path.join(dirName, "%s%s%s.%s" % (base_name, zeros, number + 1, extension))):
-					has_next_image = True
+			# Check for images which the file names have the different length
+			fixlen = fixlen or not (glob.glob("%s%s.%s" % (full_base_name, "[0-9]" * (digits + 1), extension))
+						or glob.glob("%s%s.%s" % (full_base_name, "[0-9]" * ((digits - 1) if digits > 1 else 3), extension)))
+			
+			# Check for previous or next image
+			for x in range(max(0, number - 100), min(number + 101, 50000)):
+				if x != number and os.path.exists("%s%s.%s" % (full_base_name, str(x).rjust(digits, "0") if fixlen else str(x), extension)):
+					is_sequence = True
+					break
+			else:
+				is_sequence = False
+
+			parameters = {"file_path":file_path, "folder_path":dirName, "base_name":base_name, "fixlen":fixlen, "digits":digits, "extension":extension}
 			
 			# if sibling images were found...
-			if has_previous_image or has_next_image:
+			if is_sequence:
 				# prevent repeat messageboxes... only prompt user about the first image sequence found in a single drag n drop action
 				if session not in self.project.form.file_drop_messages:
 				
@@ -270,15 +275,14 @@ class OpenShotFolder:
 		folder_path = parameters["folder_path"]
 		file_name = parameters["file_path"]
 		base_name = parameters["base_name"]
-		zeros = str(parameters["zeros"])
-		number = str(parameters["number"])
+		fixlen = parameters["fixlen"]
+		digits = parameters["digits"]
 		extension = parameters["extension"]
 		
-		zero_pattern = ""
-		if len(str(zeros)) == 0:
+		if not fixlen:
 			zero_pattern = "%d"
 		else:
-			zero_pattern = "%%0%sd" % str(len(zeros) + len(number))
+			zero_pattern = "%%0%sd" % digits
 		
 		# generate the regex pattern for this image sequence
 		pattern = "%s%s.%s" % (base_name, zero_pattern, extension)
