@@ -16,8 +16,8 @@
 #	You should have received a copy of the GNU General Public License
 #	along with OpenShot Video Editor.  If not, see <http://www.gnu.org/licenses/>.
 
-VERSION             = "1.3.0"
-DATE                = "20110213000000"
+VERSION             = "1.3.1"
+DATE                = "20110503000000"
 NAME                = 'openshot'
 GPL_VERSION         = '3'
 SUPPORTED_LANGUAGES = ['English', 'Dutch', 'French', 'German', 'Italian', 'Portuguese', 'Spanish', 'Swedish']
@@ -30,10 +30,12 @@ OG   = {'name': u'Olivier Girard', 'email': 'eolinwen@gmail.com'}
 TJ   = {'name': u'TJ', 'email': 'ubuntu@tjworld.net'}
 MA   = {'name': u'Mael Lavault', 'email': 'moimael@neuf.fr'}
 IM   = {'name': u'itomailg', 'email': 'itomailg@gmail.com'}
+JS   = {'name': u'jEsuSdA', 'email': 'info@jesusda.com'}
 
 #credits
 CREDITS = {
     'code'          : [JT, AF, TJ, OG, MA, IM],
+    'artwork'       : [JT, JS],
     'documentation' : [OG, JT, HMC],
     'translation'   : [HMC, OG],
 }
