@@ -27,6 +27,7 @@
 ####################################################################################
 
 import os, sys
+import subprocess
 import fnmatch
 import gtk
 from xml.dom import minidom
@@ -259,18 +260,28 @@ class frmNewTitle(SimpleGtkBuilderApp):
 		self.frmTitles.destroy()
 
 	def on_btnAdvanced_clicked(self, widget):
+		
+		# get translation method
+		_ = self._
+		
 		#use an external editor to edit the image
 		try:
 			prog = "inkscape"
 			#check if inkscape is installed
-			if os.system('which ' + prog + ' 2>/dev/null') == 0:
+			if subprocess.call('which ' + prog + ' 2>/dev/null', shell=True) == 0:
 				# launch Inkscape
-				os.system("%s '%s'" % (prog, self.filename))
+				p=subprocess.Popen([prog, self.filename])
+				
+				# wait for process to finish (so we can updated the preview)
+				p.communicate()
+				
+				# update image preview
+				self.set_img_pixbuf(self.filename)
 			else:
-				messagebox.show(_("OpenShot Error"), _("Please install %s to use this function." % (prog.capitalize())))
+				messagebox.show(_("OpenShot Error"), _("Please install %s to use this function.") % prog.capitalize())
 			
-		except:
-			messagebox.show(_("OpenShot Error"), _("There was an error opening '%s', is it installed?" % (prog)))
+		except OSError:
+			messagebox.show(_("OpenShot Error"), _("There was an error opening '%s', is it installed?") % prog)
 
 
 	def on_btnApply_clicked(self, widget):
